@@ -18,15 +18,10 @@ sub split_path
 	    @pre = ("..") x (length($1) - 1);
 	}
 	return(@pre, "") unless length($path);
-	# XXX if $path now contains a sequence of "." and ".." we are
-	# now in trouble...
     } else {
 	@pre = ("");
     }
-    (@pre, map { ($_ eq ".")  ? "%2E"    :
-                 ($_ eq "..") ? "%2E%2E" :
-		                do { s/%/%25/g; s/;/%3B/g; $_ }
-               } split(/:/, $path, -1));
+    (@pre, split(/:/, $path, -1));
 }
 
 sub file
