@@ -1,7 +1,5 @@
 package URI::file::Win32;
 
-use URI::Escape qw(uri_unescape);
-
 sub extract_authority
 {
     my $class = shift;
@@ -21,7 +19,7 @@ sub split_path
     my($class, $path) = @_;
     $path =~ s,[/\\][/\\]+,/,g;       # \\    --> \
     $path =~ s,([/\\]\.)+[/\\],/,g;   # \.\.\ --> \
-    map { s/%/%25/g; s/;/%3B/g; $_; } split(/[\\\/]/, $path, -1);
+    split(/[\\\/]/, $path, -1);
 }
 
 sub file
@@ -30,11 +28,10 @@ sub file
     my $auth = shift;
     my $rel;
     if ($auth) {
-        $auth = uri_unescape($auth);
-	if ($auth =~ /^([a-zA-Z])[:|](.?)/) {
-	    $auth = uc($1) . ":";
+	if ($auth =~ /^([a-zA-Z]:)(.?)/) {
+	    $auth = uc($1);
 	    $rel++ if $2;
-	} elsif (lc($auth) eq "localhost") {
+	} elsif ($auth eq "localhost") {
 	    $auth = "";
 	} else {
 	    $auth = "\\\\" . $auth;  # UNC
